#Materials and Methods

##Compilation of human quantitative phosphoproteomic data
The atlas integrates a compilation of  41 selected publications reporting human MS-derived changes in phosphopeptide abundance under 435 perturbations. In order to consider a dataset for the atlas, we required peptide sequences, phosphorylation identifications and detailed description of the biological perturbation and control for a minimum of 1000 phosphopeptides (Table EV1). From the 41 studies included, only the raw spectra derived from 16 studies was made available in public repositories. 3 additional studies were deposited in the no longer available Tranche. For the remaining 16 studies, the different labelling methodologies difficult the spectra processing with a common pipeline, the most frequent being SILAC in 10 studies.  Additionally, due to the poor metadata annotation of some of the conditions, re-processing the spectra would not be possible for some of the datasets. For these reasons we relied on the original MS identifications performed by the experimental groups. We collected all quantifications from the supplementary data available in each of the 41 studies, including both significant and not significant changes. To standardize the peptide sequences and site positions across studies, we mapped all peptides to the same reference proteome using Ensembl v73 \cite{25352552}. For data storage purposes, we mapped the peptide quantifications to all matching protein isoforms and transformed all quantifications into \(\log_{2}\) ratios. Finally, the re-mapped 2,940,379 phosphopeptide quantifications and all their metadata were stored in a MySQL database that is publicly available in the Downloads section of [http://phosfate.com](http://phosfate.com).

##Data pre-processing and normalization
To standardize and further compare the datasets, we applied a series of quality control criteria. (a) we restricted the analysis to peptides mapped in the Ensembl canonical transcripts, resulting in 12,427 canonical phospho-modified proteins. According to Ensembl, the canonical transcripts correspond to the longest Consensus CDS (CCDS) model in each gene \cite{19498102}. (b) the quantified changes of peptides with the same set of modifications but different sequences were merged into one single entry, therefore increasing the conditional coverage. On those cases where more than one quantified peptide contains the same set of modifications for the same condition their ratios were averaged. (c) the conditional ratios between technical replicates were averaged, while remaining separated for biological replicates. (d) only monophosphorylated peptides were considered for all subsequent analysis requiring quantifications at single positions. (e) to prevent the accumulation of false positive sites, modified positions identified only in one single study were excluded. (f) we quantile normalized the quantifications across conditions and excluded all conditions with less than 1000 peptide quantifications. After applying all these quality control criteria, the size of the final set of conditions was reduced from 435 to 399 perturbations (Appendix Fig S1). On this reduced set of conditions, we considered for further analysis a total of 1.238.987 quantifications for 43.028 more reliable monophosphorylated peptides.

##Kinase Set Enrichment Analysis (KSEA)
To estimate the kinase regulation from the differential regulation of their known substrates, we modified the original Kinase Set Enrichment Analysis (KSEA) to incorporate the principles of the weighted Gene Set Enrichment Analysis \cite{23532336,16199517}. This modified KSEA uses the Kolmogorov-Smirnov statistical test to assess whether a predefined set of kinase substrates is statistically enriched in phosphosites that are at the two of extremes of a ranked list defined by their differential regulation. This algorithm is particularly helpful to detect changes on phosphosite regulation in the context of all site quantifications, even though the changes in site quantifications could be small. Moreover, the algorithm do not require any arbitrary threshold to define which phosphosites are significantly regulated or not. As in the GSEA algorithm, all site quantifications are considered in order to search for enrichments within the extreme fold changes. The KSEA algorithm proceeds as follows: (a) The Enrichment Score (ES) is calculated by walking down the ranked site quantifications and re-scoring a running-sum statistic. The statistic is increased by the site quantification when it encounters a substrate of the kinase and decreases when the site is not a substrate. Both increases and decreases are normalized by the total number of known and not known substrates and proportional to the observed fold change. Finally, the ES corresponds to the maximum deviation from zero - either positive or negative - encountered in the walking down. The metric is equivalent to a weighted Kolmogorov–Smirnov-like statistic. (b) The null distribution of ES scores is calculated by randomizing the sites but preserving the same distribution of site quantifications. (c) The statistical significance of the observed ES is calculated using the empirical *p*-values calculated from the ES null distribution based on the same number of known substrates and the same distribution of quantifications. An R package implementing the novel KSEA described above is provided at https://github.com/evocellnet/ksea.

##Predicting kinase activities using KSEA
In order to collect a comprehensive list of regulatory relationships, we merged all the interactions reported in PhosphoSitePlus \cite{25514926}, HPRD \cite{18988627} and Phospho.ELM \cite{21062810} in June 2014. After excluding kinase auto-phosphorylations, we compiled a total of 7,815 interactions between 306 kinases and 5,617 individual sites. Using the above described regulatory information and the collected quantitative phosphoproteomic data, we applied the KSEA algorithm with a null distribution of 1,000 permutations per kinase and condition. In order to use the enrichment significance as a proxy of kinase activity, the resulting *p*-values were \(log_{10}\)-transformed and signed based on the average sign of all substrates. If the predominant change of all substrates is an increase in phosphorylation, the kinase is predicted as activated. If the majority of the substrates present reduced phosphorylation, the kinase is predicted as inactivated.

## Kinase activity validation using kinase regulatory sites
To corroborate the kinase activity inference, KSEA activities were compared with the phosphorylation changes observed in kinase regulatory sites across conditions. From the total list of 941 human regulatory sites reported in PhosphositePlus, 150 were quantified in at least 10 perturbations. To evaluate the concordance between the KSEA activities and the quantitative changes in the regulatory phosphorylations, we performed a linear regression analysis across all available perturbations. Additionally, the results with those derived from the Spearman correlations between the kinase activities and the regulatory sites susceptible of auto-phosphorylation and other sites not reported to regulate the enzymatic activity. We discarded all kinase activity profiles under no regulation (absolute log *p*-value > 1 in at least 1 condition). 

## Kinase activity validation using RPPA data
We compared the predictions based on the collected quantitative phosphoproteomic data with the antibody-based kinase activities from a previous study \cite{26901648}. We used the BT20 cell line as reference, showing the most responsive quantitative profiles after EGF receptor stimulation. We scaled the antibody-based measurements to make them comparable across conditions and antibodies. We quantile-normalized per antibody to assure equal final distributions. Next, we standardized each individual combination of cell line, inhibitor, stimulus and time point by calculating the z-score of each of the measurements based on the mean and standard deviation of the unstimulated conditions. Replicates were averaged. The final dataset contains 26 quantifications reporting changes in regulatory phosphosites in kinases. In order to use only the most reliable activity predictions, kinases with a number of known substrates smaller than 5 were excluded. To circumvent the effect of protein abundances, we restricted the analysis to the first hour after EGF stimulation. The normalized quantifications clustered together based on the sample similarities, with no apparent batch effects (Appendix Fig S1). The DREAM conditions were classified depending if they activate EGFR - EGF and NRG1 - other growth factors that eventually could have a similar downstream effects - HGF, IGF1, FGF1 and Insulin - or non-stimulating conditions - Serum and PBS.

## Maintenance and treatment of human embryonic stem cells (hESC)
Human embryonic cells, H1 and H9 (WA01, WA09 from WiCell) were maintained on Matrigel (BD Biosciences) coated dishes in mTeSR™1 medium (StemCell Technologies). Differentiation of hESCs was induced by supplementing mTeSR™1 with PMA 50 nM. Differentiation time course experiments were typically 0 min, 30 min, 1 hour, 6 hours and 24 hours. Kinase inhibition experiments requiring were performed by supplementing mTeSR™1 medium with pharmacological inhibitors 1 hour before PMA treatments (Table EV8). In order to avoid inhibitor’s degradation during 24h experiment, fresh mTeSR™1 medium with a 50 nM of PMA was changed after 10 hours.

##hESC Immunofluorescence and image analysis
For each time course experiment, hESC were fixed for 10 minutes with a 4% paraformaldehyde, permeabilized for 5min with 0.3% Triton-x and incubated with a blocking solution (10% fetal bovine serum (FBS) and 3% bovine serum albumin (BSA) in PBS) for 1h. Primary antibodies (Table EV7) were incubated ON at 4 °C in antibody dilution buffer (1% bovine serum albumin (BSA). 0.1% Triton-x in PBS) at the indicated concentrations. Primary antibodies were visualized by using a secondary antibody conjugated to Alexa-488. Samples were counterstained with DAPI to facilitate analysis. Images were acquired using a high-content, widefield inverted microscope, Olympus ScanR System equipped with a sCMOS Flash 4.0 camera (Hamamatsu), universal plan semi-aprochromat 20x objective (NA 0.7) and a SpectraX LED light source. Image analysis was performed using Matlab or CellProfiler \cite{17076895}. Briefly, a low-pass Gaussian filter was first applied to each image. The local background value of each pixel was then determined by searching for a surrounding ring area, with the outer and inner radii of the ring being 10 and 5 times the approximate nuclear radius, respectively. The lowest 5th percentile value of the ring area was used as the background intensity of the center pixel. Cell nuclei were identified using fluorescent DAPI images as masks. When needed cytoplasmic mask consisted of a ring around the nucleus. The MATLAB function *regionprops* was then used to label each nucleus and to retrieve the xy coordinates of all pixels in specific nuclei. The level of immunofluorescence staining in each cell was calculated as the average value of the intensities from each pixel of the specific nucleus. At least 2000 cells were used for analysis per each indicated condition.

## PCA based on kinase activity profiles
To restrict the analysis to consistently estimated kinases, only those inferred in at least 75% of the perturbations were considered. Conditions displaying extreme redundancies were also excluded, reducing the matrix of kinase activities to 58 kinases and 387 conditions. For the 7.43% of the matrix containing missing values, the data was imputed using the regularized iterative PCA algorithm implemented in the *imputePCA* function contained in the R package *missMDA*. Using the resulting complete matrix Principal Components Analysis (PCA) was performed using the *rda* function in the R package *vegan* without any additional scaling. The expected (baseline) per cent variance in each PC stemming from noise in data was estimated using the stringent ‘broken stick’ method and the relaxed average eigenvalue (Kaiser–Guttman criterion) \cite{Jackson_1993}.

##Salmonella strains used for infection
Salmonella enterica Typhimurium 14028s (STm) transformed with the constitutive GPF expressing plasmid pDiGc \cite{20133586} were cultivated in LB broth (Miller) containing 100\(\mu\)g/ml ampicillin by incubating on a rotating wheel at 37°C. HeLa cells (ATCC) were cultivated in DMEM 4.5 g/L glucose (Gibco cat. # 41965-039), pyruvate (100mM,Gibco), 10% FBS at 5% CO2 in a 37°C incubator. Stock drug solutions were dissolved in DMSO: trichostatin A (Sigma cat. T8552) and SB202190 (Sigma cat. S7067), or methanol: (±)-Verapamil hydrochloride (Sigma cat. V4629). Final drug concentrations used trichostatin A: 1.5, 1.0 and 0.5 \(\mu\)M, SB202190 15, 10 and 5 \(\mu\)M, (±)-Verapamil hydrochloride: 15, 10 and 5 \(\mu\)M. 100mg/mL stock solution of Gentamicin was dissolved in water (Sigma cat. G1914).Bacteria were prepared for HeLa cell invasion as previously described 20133586 \cite{20133586} with the following modifications: overnight cultures of GFP expressing STm were diluted 1:33 into fresh LB broth and cultured for 3.5 hrs at 37°C prior to infection.

##HeLa cell preparation and infection 
At 80% confluency, 3000 HeLa cells per well were seeded into a 384 wells clear bottom plate (Greiner cat. 781090) using a cell seeder (Thermo, Multidrop Combi) followed by an 18hr incubation overnight to allow cell attachment. Cells were then exposed to indicated drug concentrations in the presence of DMEM 1 g/L glucose + 10% FBS for 6 hrs. Prior to infection, cells were then washed 2 times with DMEM or PBS, followed by media replacement with fresh DMEM 1 g/L glucose + 10% FBS. Infection was carried out as previously described \cite{20133586} using a liquid handler (Biomek FXP). STm was added directly to HeLa cells at an MOI of 100 in PBS. STm was then allowed to invade HeLa cells by incubating for 30 minutes at 5% CO2 in a 37°C incubator. Extracellular STm were then removed by washing 3 times with warm PBS, followed by treatment with 100 \(\mu\)g/mL gentamicin in DMEM 1 g/L glucose + 10% FBS for 1 hr. Media was then replaced with 10 \(\mu\)g/mL gentamicin in DMEM 1 g/L glucose + 10% FBS for the remainder of the experiment n.b. this step was considered t=0. At the indicated time points, cells were then washed with prewarmed PBS prior to fixation and permeabilization in 5% formaldehyde/0.2% Tritonx100 in PBS for 45 minutes. Fixing solution was then removed by washing with PBS and cells were stained using 2.5 \(\mu\)g/mL Hoechst33342 (Molecular Probes cat.  H3570)  and 80 ng/mL Phalloidin-Atto700 (Sigma cat. 79286) overnight at 4°C. Prior to imaging cells were washed 3 times in PBS.

##Salmonella microscopy and image analysis
384-well plates were imaged using a Molecular Devices, IXM XL microscope where 6 sites per well were imaged at 20x maginfication. Cellprofiler was used to analyze the images. Nuclear regions were determined by setting a manual intensity threshhold for the DAPI channel. Nuclei were expanded using the actin staining to determine the cellular regions. Salmonella colonies were determined by manual threshholding. Segmented cells were classified as infected or  non-infected depending on the presence or the absence of a salmonella colony in a cell region. For every site imaged, the number of infected and non-infected cells was determined, along with the integrated salmonella fluorescence intensity inside infected cells. To determine the percentage of infected cells per well, the number of infected and non-infected cells from the 6 sites of every well was summed up and the ratio of infection was calculated. In addition, the mean integrated intesity of Salmonella in infected cells was determined for every site, and the average value for the 6 sites in a well was calculated to obtain the mean integrated intensity of salmonella in infected cells per well as a measure of salmonella intracellular proliferation.

## Co-regulation between driver kinases and effector complexes 
We first quantified the phospho-regulation of stable human complexes (from the Corum database \cite{19884131}) in each condition. We limited the complex redundancy by subsetting the interactions in which only one copy of the homologous protein complexes is included. For each of the 1,331 complexes and for each condition, we compared the distribution of absolute changes in phosphosite abundance in the complex against all phosphosites using the Kolmogorov-Smirnov (KS) test. The resulting *p*-values were log-transformed and signed based on the average fold change of all sites in the complex. We then fitted a linear regression to estimate those responses in protein complex phosphorylation that correlate with changes in kinase activity across conditions. For validation purposes and in order to avoid potential biases, the kinase substrates used to predict the kinase activities were excluded from the complex regulation estimates. The Pearson correlation *p*-values were corrected for multiple testing.

## SILAC labelling, protein extraction and digestion
HeLa cells were passaged in DMEM (-Arg,-Lys) with penicillin-streptomycin, 10% dialyzed FBS at 37°C, 5% \(CO_{2}\), supplemented with either normal L-lysine and L-arginine (light K0, R0) or \(^{13}C_{6}\)-\(^{15}N_{2}\) lysine and \(^{13}C_{6}\)-\(^{15}N_{4}\) arginine (heavy K8, R10). Both populations of cells were deprived of serum overnight. 'Light' labeled cells were treated with 1\(\mu\)M Akt inhibitor VIII for 30 min prior to stimulation with 100 nM insulin for an additional 30 min. 'Heavy' labeled cells were stimulated with 100 nM insulin for 30 min. At the time of harvest, cells were washed three times with ice cold PBS and flash frozen over liquid nitrogen. Cells were scraped into ice-cold urea buffer (8M urea, 75 mM NaCl, 50 mM Tris HCl pH 8.2, complete protease inhibitor cocktail (Roche), 50 mM sodium fluoride, 50 mM beta-glycerophosphate, 1 mM sodium orthovanadate, 10 mM sodium pyrophosphate). Protein concentration was assayed using the BCA method and lysates from 'light' and 'heavy' cultures were mixed in a 1:1 ratio. Protein lysates were reduced with 5 mM DTT for 30 min at 55°C, alkylated with 10 mM iodoacetamide for 15 min at room temperature, and quenched with 10 mM DTT. Proteins were diluted 2-fold with 50 mM Tris pH 8.8 and digested with Lys-C (Wako) overnight at room temperature. The resulting peptides were desalted over a tC18 SepPak cartridge (Waters) and dried by lyophilization. 

## Strong cation exchange (SCX)/Immobilized metal affinity chromatography (IMAC)
Approximately 3 mg of peptides were resuspended in 50 mM Tris pH 8.2 and further digested with trypsin (Promega) overnight at 37°C. The resulting tryptic peptides were desalted over a tC18 SepPak cartridge (Waters) and dried by vacuum centrifugation. They were separated by strong cation exchange into 12 fractions using a volatile binary solvent system (A: 10 mM \(NH_{4}HCO_{2}\) + 25% MeCN + 0.05% FA, B: 500 mM \(NH_{4}HCO_{2}\) + 25% MeCN + 0.05% FA). Fractions were dried and desalted by vacuum centrifugation. Fractions were resuspended in 100 \(\mu\)l IMAC loading solution (80% MeCN+ 0.1% TFA). To prepare IMAC slurry, Ni-NTA magnetic agarose (Qiagen) was stripped with 40 mM EDTA for 30 min, reloaded with 10 mM \(FeCl_{3}\) for 30 min, washed 3 times and resuspended in IMAC loading solution. To enrich phosphopeptides, 50 \(\mu\)l of 5% bead slurry was added to each fraction and incubated with rotation for 30 min at room temperature, washed 3 times with 150 \(\mu\)l 80% MeCN, 0.1% TFA, and eluted with 60 \(\mu\)l 1:1 MeCN:1% \(NH_{4}OH\). The eluates were acidified with 10% FA and dried by vacuum centrifugation for LC-MS/MS.

## LC-MS/MS
Phosphopeptide-enriched samples were resuspended in 4% formic acid, 3% MeCN and subjected to liquid chromatography on an EASY-nLC II system equipped with a 100 \(\mu\)m inner diameter x 40 cm column packed in-house with Reprosil C18 1.9 \(\mu\)m particles (Dr. Maisch GmbH) and column oven set to 50°C. Separations were performed using gradients of 9% to 32% MeCN in 0.125% formic acid ranging in length from 55-105 min and were coupled directly with a LTQ-Orbitrap Velos mass spectrometer (Thermo Fisher) configured to conduct a full MS scan (60k resolution, 3e6 AGC target, 500 ms maximum injection time, 300 to 1500 m/z) followed by up to 20 data-dependent MS/MS acquisitions on the top 20 most intense precursor ions (3e3 AGC target, 100 ms maximum injection time, 35% normalized collision energy, 40 sec dynamic exclusion).

## LC-MS/MS data processing
Raw data files were converted to mzXML and searched using Comet version 2015.01 against the human Swissprot database including reviewed isoforms (April 2015; 42,121 entries) allowing for binary (all or none) labeling of lysine (+8.0142) and arginine (+10.0083), and variable oxidation of methionine, protein N-terminal acetylation, and phosphorylation of serine, threonine, and tyrosine residues. Carbamidomethylation of cysteines was set as a fixed modification. Trypsin (KR|P) fully digested was selected allowing for up to 2 missed cleavages. Precursor mass tolerance was set to 50 ppm, and fragment ion tolerance to 1.0005 Daltons. Search results were filtered using Percolator to reach a 1% false discovery rate at the PSM level. Peak area Heavy/Light ratios were calculated using an in-house quantification algorithm. Phosphosite assignment was performed using an in-house implementation of Ascore, and sites with Ascore \(\ge\) 13 were considered localized (\(p=0.05\)). Phosphopeptides in the database with multiple non-localized instances spanning the same sequence were only considered to correspond to the minimum number of phosphosites that explain the data. Finally, the dataset was additionally filtered to reach a site-adjusted false discovery rate of 1%.

##Co-regulation between Akt and potential new substrates
For all human phosphorylated residues compiled in the atlas, a series of evidences were generated in  order to weight their potential role as substrates of AKT. Firstly, all sites in the atlas were matched against the position weight matrixes (PWM) generated from all the known substrates of AKT. To weight the motif - PWM similarity, two algorithms were compared with similar results: the sum of the log weights of the matched residues and the MSS score provided by MATCH, which incorporates the information content of the PWM \cite{12824369,15131651}. Secondly, the aforementioned inference of kinase activities based on the known kinase substrates was used to find sites co-regulated with the known substrates of AKT. The response of all sites in the atlas across the panel of conditions were correlated with the estimated activity of AKT in the same conditions. We also included as an additional validation the set of  1,778 AKT *in vitro* substrates described by Imamura *et al.* \cite{24869485}. Finally, as a fourth independent evidence we included the differential regulation of each of the candidate AKT sites under inhibition by AKT inhibitor VIII in insulin-stimulated HeLa cells described above.   


  
  
  
  
  
  
  